@@ -6,7 +6,7 @@ import re
 import xml.etree.ElementTree as ET
 
 from pathlib import Path
-from typing import List, Tuple, Union
+from typing import List, Tuple
 
 import requests
 
@@ -15,12 +15,14 @@ from qgis_plugin_repo.tools import is_url
 
 class Dispatcher:
 
-    def __init__(self, input_uri: Union[Path, str], outputs_uri: List[Union[Path, str]]):
+    def __init__(self, input_uri: str, outputs_uri: List[str]):
         """ Constructor. """
-        self.input_uri = input_uri
+
         if is_url(input_uri):
+            self.input_uri = input_uri
             self.input_parser = ET.fromstring(requests.get(self.input_uri).content)
         else:
+            self.input_uri = Path(input_uri)
             self.input_parser = ET.parse(self.input_uri.absolute()).getroot()
 
         self.outputs_uri = [Path(f) for f in outputs_uri]
